@@ -235,7 +235,16 @@ object NextTurnAutomation {
                     val valueOfOne = evaluation.evaluateSellCost(TradeOffer(ourGold.name, ourGold.type, 1, ourGold.duration), civInfo, otherCiv)
                     val amountToGive = min(deltaInOurFavor / valueOfOne, ourGold.amount)
                     deltaInOurFavor -= amountToGive * valueOfOne
-                    counterofferGifts.add(TradeOffer(ourGold.name, ourGold.type, amountToGive, ourGold.duration))
+                    if (amountToGive > 0) {
+                        counterofferGifts.add(
+                            TradeOffer(
+                                ourGold.name,
+                                ourGold.type,
+                                amountToGive,
+                                ourGold.duration
+                            )
+                        )
+                    }
                 }
             }
         }
@@ -303,7 +312,7 @@ object NextTurnAutomation {
 
         if (!civInfo.isCityState()) {
             val potentialAllies = civInfo.getKnownCivs().filter { it.isCityState() }
-            if (potentialAllies.isNotEmpty()) {
+            if (potentialAllies.any()) {
                 val cityState =
                     potentialAllies.maxByOrNull { valueCityStateAlliance(civInfo, it) }!!
                 if (cityState.getAllyCiv() != civInfo.civName && valueCityStateAlliance(civInfo, cityState) > 0) {
@@ -327,6 +336,12 @@ object NextTurnAutomation {
     private fun maybeBuyCityTiles(civInfo: Civilization) {
         if (civInfo.gold <= 0)
             return
+        // Don't buy tiles in the very early game. It is unlikely that we already have the required
+        // tech, the necessary worker and that there is a reasonable threat from another player to
+        // grab the tile. We could also check all that, but it would require a lot of cycles each
+        // turn and this is probably a good approximation.
+        if (civInfo.gameInfo.turns < (civInfo.gameInfo.speed.scienceCostModifier * 20).toInt())
+            return
 
         val highlyDesirableTiles: SortedMap<Tile, MutableSet<City>> = TreeMap(
             compareByDescending<Tile?> { it?.naturalWonder != null }
@@ -347,7 +362,8 @@ object NextTurnAutomation {
                         (it.hasViewableResource(civInfo)
                                 && it.tileResource.resourceType == ResourceType.Strategic &&
                                 (civInfo.getCivResourcesByName()[it.resource!!] ?: 0) <= 3)
-                it.isVisible(civInfo) && it.getOwner() == null &&
+                it.isVisible(civInfo) && it.getOwner() == null
+                        && it.neighbors.any { neighbor -> neighbor.getCity() == city }
                         (hasNaturalWonder || hasLuxuryCivDoesntOwn || hasResourceCivHasNoneOrLittle)
             }
             for (highlyDesirableTileInCity in highlyDesirableTilesInCity) {
@@ -572,7 +588,7 @@ object NextTurnAutomation {
      *  a unit and selling a building to make room. Can happen due to trades etc */
     private fun freeUpSpaceResources(civInfo: Civilization) {
         // No need to build spaceship parts just yet
-        if (civInfo.gameInfo.ruleset.victories.none { civInfo.victoryManager.getNextMilestone(it.key)?.type == MilestoneType.AddedSSPartsInCapital } )
+        if (civInfo.gameInfo.ruleset.victories.none { civInfo.victoryManager.getNextMilestone(it.value)?.type == MilestoneType.AddedSSPartsInCapital } )
             return
 
         for (resource in civInfo.gameInfo.spaceResources) {
@@ -793,7 +809,7 @@ object NextTurnAutomation {
         // If the AI declares war on a civ without knowing the location of any cities, it'll just keep amassing an army and not sending it anywhere,
         //   and end up at a massive disadvantage
 
-        if (enemyCivs.isEmpty()) return
+        if (enemyCivs.none()) return
 
         val civWithBestMotivationToAttack = enemyCivs
                 .map { Pair(it, motivationToAttack(civInfo, it)) }
@@ -962,15 +978,21 @@ object NextTurnAutomation {
     }
 
     private fun automateCities(civInfo: Civilization) {
+        val ownMilitaryStrength = civInfo.getStatForRanking(RankingType.Force)
+        val sumOfEnemiesMilitaryStrength = civInfo.gameInfo.civilizations.filter { it != civInfo }
+            .filter { civInfo.isAtWarWith(it) }.sumOf { it.getStatForRanking(RankingType.Force) }
+        val civHasSignificantlyWeakerMilitaryThanEnemies =
+                ownMilitaryStrength < sumOfEnemiesMilitaryStrength * 0.66f
         for (city in civInfo.cities) {
             if (city.isPuppet && city.population.population > 9
-                    && !city.isInResistance()) {
+                    && !city.isInResistance()
+            ) {
                 city.annexCity()
             }
 
             city.reassignAllPopulation()
 
-            if (city.health < city.getMaxHealth()) {
+            if (city.health < city.getMaxHealth() || civHasSignificantlyWeakerMilitaryThanEnemies) {
                 Automation.tryTrainMilitaryUnit(city) // need defenses if city is under attack
                 if (city.cityConstructions.constructionQueue.isNotEmpty())
                     continue // found a unit to build so move on
@@ -1014,7 +1036,7 @@ object NextTurnAutomation {
                 }
 
             if (highestOpinion == null) null
-            else knownMajorCivs.filter { civInfo.getDiplomacyManager(it).opinionOfOtherCiv() == highestOpinion}.random().civName
+            else knownMajorCivs.filter { civInfo.getDiplomacyManager(it).opinionOfOtherCiv() == highestOpinion}.toList().random().civName
 
         } else {
             civInfo.getAllyCiv()
