@@ -1,5 +1,6 @@
 package com.unciv.logic.city
 
+import com.unciv.GUI
 import com.unciv.UncivGame
 import com.unciv.logic.IsPartOfGameInfoSerialization
 import com.unciv.logic.automation.Automation
@@ -21,13 +22,14 @@ import com.unciv.models.ruleset.unit.BaseUnit
 import com.unciv.models.stats.Stat
 import com.unciv.models.stats.Stats
 import com.unciv.models.translations.tr
-import com.unciv.ui.screens.civilopediascreen.CivilopediaCategories
-import com.unciv.ui.screens.civilopediascreen.FormattedLine
 import com.unciv.ui.components.Fonts
 import com.unciv.ui.components.extensions.withItem
 import com.unciv.ui.components.extensions.withoutItem
+import com.unciv.ui.screens.civilopediascreen.CivilopediaCategories
+import com.unciv.ui.screens.civilopediascreen.FormattedLine
 import com.unciv.ui.screens.worldscreen.unit.actions.UnitActions
 import kotlin.math.ceil
+import kotlin.math.min
 import kotlin.math.roundToInt
 
 
@@ -287,7 +289,7 @@ class CityConstructions : IsPartOfGameInfoSerialization {
             city.getRuleset().buildings[it]
                     ?: throw java.lang.Exception("Building $it is not found!")
         })
-        updateUniques()
+        updateUniques(true)
     }
 
     fun addProductionPoints(productionToAdd: Int) {
@@ -313,13 +315,17 @@ class CityConstructions : IsPartOfGameInfoSerialization {
             val productionCost = (construction as INonPerpetualConstruction).getProductionCost(city.civ)
             if (inProgressConstructions.containsKey(currentConstructionFromQueue)
                     && inProgressConstructions[currentConstructionFromQueue]!! >= productionCost) {
-                productionOverflow = inProgressConstructions[currentConstructionFromQueue]!! - productionCost
-                // See the URL below for explanation for this cap
-                // https://forums.civfanatics.com/threads/hammer-overflow.419352/
-                val maxOverflow = maxOf(productionCost, city.cityStats.currentCityStats.production.roundToInt())
-                if (productionOverflow > maxOverflow)
-                    productionOverflow = maxOverflow
-                constructionComplete(construction)
+                val potentialOverflow = inProgressConstructions[currentConstructionFromQueue]!! - productionCost
+                if (constructionComplete(construction)){
+                    // See the URL below for explanation for this cap
+                    // https://forums.civfanatics.com/threads/hammer-overflow.419352/
+                    val maxOverflow = maxOf(productionCost, city.cityStats.currentCityStats.production.roundToInt())
+                    productionOverflow = min(maxOverflow, potentialOverflow)
+                }
+                else {
+                    city.civ.addNotification("No space available to place [${construction.name}] near [${city.name}]",
+                        city.location, NotificationCategory.Production, construction.name)
+                }
             }
         }
     }
@@ -343,7 +349,19 @@ class CityConstructions : IsPartOfGameInfoSerialization {
         constructionQueue.clear()
 
         for (constructionName in queueSnapshot) {
-            if (getConstruction(constructionName).isBuildable(this))
+            val construction = getConstruction(constructionName)
+            // First construction will be built next turn, we need to make sure it has the correct resources
+            if (constructionQueue.isEmpty() && getWorkDone(constructionName) == 0) {
+                val costUniques = construction.getMatchingUniquesNotConflicting(UniqueType.CostsResources)
+                val civResources = city.civ.getCivResourcesByName()
+
+                if (costUniques.any {
+                            val resourceName = it.params[1]
+                            civResources[resourceName] == null
+                                    || it.params[0].toInt() > civResources[resourceName]!! })
+                    continue // Removes this construction from the queue
+            }
+            if (construction.isBuildable(this))
                 constructionQueue.add(constructionName)
         }
     }
@@ -386,6 +404,14 @@ class CityConstructions : IsPartOfGameInfoSerialization {
     }
 
     private fun constructionBegun(construction: IConstruction) {
+        val costUniques = construction.getMatchingUniquesNotConflicting(UniqueType.CostsResources)
+
+        for (unique in costUniques){
+            val amount = unique.params[0].toInt()
+            val resourceName = unique.params[1]
+            city.civ.resourceStockpiles.add(resourceName, -amount)
+        }
+
         if (construction !is Building) return
         if (!construction.hasUnique(UniqueType.TriggersAlertOnStart)) return
         val buildingIcon = "BuildingIcons/${construction.name}"
@@ -404,8 +430,11 @@ class CityConstructions : IsPartOfGameInfoSerialization {
         }
     }
 
-    private fun constructionComplete(construction: INonPerpetualConstruction) {
-        construction.postBuildEvent(this)
+    /** Returns false if we tried to construct a unit but it has nowhere to go */
+    private fun constructionComplete(construction: INonPerpetualConstruction): Boolean {
+        val managedToConstruct = construction.postBuildEvent(this)
+        if (!managedToConstruct) return false
+
         if (construction.name in inProgressConstructions)
             inProgressConstructions.remove(construction.name)
         if (construction.name == currentConstructionFromQueue)
@@ -425,7 +454,8 @@ class CityConstructions : IsPartOfGameInfoSerialization {
             }
         } else {
             val icon = if (construction is Building) buildingIcon else construction.name // could be a unit, in which case take the unit name.
-            city.civ.addNotification("[${construction.name}] has been built in [" + city.name + "]",
+            city.civ.addNotification(
+                "[${construction.name}] has been built in [${city.name}]",
                     city.location, NotificationCategory.Production, NotificationIcon.Construction, icon)
         }
 
@@ -441,6 +471,7 @@ class CityConstructions : IsPartOfGameInfoSerialization {
                     NotificationCategory.General, NotificationIcon.Construction, buildingIcon)
             }
         }
+        return true
     }
 
     fun addBuilding(buildingName: String) {
@@ -457,10 +488,11 @@ class CityConstructions : IsPartOfGameInfoSerialization {
         updateUniques()
     }
 
-    fun updateUniques() {
+    fun updateUniques(onLoadGame:Boolean = false) {
         builtBuildingUniqueMap.clear()
         for (building in getBuiltBuildings())
             builtBuildingUniqueMap.addUniques(building.uniqueObjects)
+        if (!onLoadGame) city.cityStats.update()
     }
 
     fun addFreeBuildings() {
@@ -673,8 +705,7 @@ class CityConstructions : IsPartOfGameInfoSerialization {
         city.cityStats.update()
         city.civ.cache.updateCivResources()
         // If bought the worldscreen will not have been marked to update, and the new improvement won't show until later...
-        if (UncivGame.isCurrentInitialized() && UncivGame.Current.worldScreen != null)
-            UncivGame.Current.worldScreen!!.shouldUpdate = true
+        GUI.setUpdateWorldOnNextRender()
     }
 
     /** Support for [UniqueType.CreatesOneImprovement]:
