@@ -2,7 +2,7 @@ package com.unciv.logic.civilization.managers
 
 import com.badlogic.gdx.math.Vector2
 import com.unciv.Constants
-import com.unciv.UncivGame
+import com.unciv.GUI
 import com.unciv.logic.GameInfo
 import com.unciv.logic.IsPartOfGameInfoSerialization
 import com.unciv.logic.civilization.CivFlags
@@ -778,8 +778,8 @@ class QuestManager : IsPartOfGameInfoSerialization {
         val civilizationsToFind = challenger.getKnownCivs()
                 .filter { it.isAlive() && it.isMajorCiv() && !challenger.hasMetCivTerritory(it) }
 
-        if (civilizationsToFind.isNotEmpty())
-            return civilizationsToFind.random()
+        if (civilizationsToFind.any())
+            return civilizationsToFind.toList().random()
 
         return null
     }
@@ -797,7 +797,7 @@ class QuestManager : IsPartOfGameInfoSerialization {
         val validTargets = civInfo.getKnownCivs().filter { it.isCityState() && challenger.knows(it)
                 && civInfo.proximity[it.civName] == closestProximity }
 
-        return validTargets.randomOrNull()
+        return validTargets.toList().randomOrNull()
     }
 
     /** Returns a [Civilization] of the civ that most recently bullied [civInfo].
@@ -835,16 +835,14 @@ class AssignedQuest(val questName: String = "",
     }
 
     fun onClickAction() {
-        val game = UncivGame.Current
-
         when (questName) {
             QuestName.ClearBarbarianCamp.value -> {
-                game.resetToWorldScreen()
-                game.worldScreen!!.mapHolder.setCenterPosition(Vector2(data1.toFloat(), data2.toFloat()), selectUnit = false)
+                GUI.resetToWorldScreen()
+                GUI.getMap().setCenterPosition(Vector2(data1.toFloat(), data2.toFloat()), selectUnit = false)
             }
             QuestName.Route.value -> {
-                game.resetToWorldScreen()
-                game.worldScreen!!.mapHolder.setCenterPosition(gameInfo.getCivilization(assigner).getCapital()!!.location, selectUnit = false)
+                GUI.resetToWorldScreen()
+                GUI.getMap().setCenterPosition(gameInfo.getCivilization(assigner).getCapital()!!.location, selectUnit = false)
             }
         }
     }
