@@ -175,6 +175,21 @@ enum class UniqueParameterType(
         }
     },
 
+    /** Implemented by [Nation.matchesFilter][com.unciv.models.ruleset.Building.matchesFilter] */
+    NationFilter("nationFilter", Constants.cityStates) {
+        private val knownValues = setOf(Constants.cityStates, "Major", "All")
+
+        override fun getErrorSeverity(
+            parameterText: String,
+            ruleset: Ruleset
+        ): UniqueType.UniqueComplianceErrorSeverity? {
+            if (parameterText in knownValues) return null
+            if (ruleset.nations.containsKey(parameterText)) return null
+            if (ruleset.nations.values.any { it.hasUnique(parameterText) }) return null
+            return UniqueType.UniqueComplianceErrorSeverity.RulesetSpecific
+        }
+    },
+
     /** Implemented by [CityInfo.matchesFilter][com.unciv.logic.city.City.matchesFilter] */
     CityFilter("cityFilter", "in all cities", null, "City filters") {
         private val cityFilterStrings = setOf(
@@ -235,19 +250,6 @@ enum class UniqueParameterType(
             parameterText != "All" && getErrorSeverity(parameterText, ruleset) == null
     },
 
-        /** [UniqueType.PercentProductionConstructions], [UniqueType.PercentProductionConstructionsCities] */
-        @Deprecated("as of 3.17.10 - removed 3.18.5")
-        ConstructionFilter("constructionFilter", "Spaceship Part") {
-            override fun getErrorSeverity(
-                parameterText: String,
-                ruleset: Ruleset
-            ): UniqueType.UniqueComplianceErrorSeverity? {
-                if (BuildingFilter.getErrorSeverity(parameterText, ruleset) == null) return null
-                if (BaseUnitFilter.getErrorSeverity(parameterText, ruleset) == null) return null
-                return UniqueType.UniqueComplianceErrorSeverity.WarningOnly
-            }
-        },
-
     /** Implemented by [PopulationManager.getPopulationFilterAmount][com.unciv.logic.city.CityPopulationManager.getPopulationFilterAmount] */
     PopulationFilter("populationFilter", "Followers of this Religion", null, "Population Filters") {
         private val knownValues = setOf("Population", "Specialists", "Unemployed", "Followers of the Majority Religion", "Followers of this Religion")
