@@ -58,6 +58,11 @@ object UniqueTriggerActivation {
                         || unit.hasUnique(UniqueType.FoundCity) && civInfo.isOneCityChallenger())
                     return false
 
+                val limit = unit.getMatchingUniques(UniqueType.MaxNumberBuildable)
+                    .map { it.params[0].toInt() }.minOrNull()
+                if (limit!=null && limit <= civInfo.units.getCivUnits().count { it.name==unitName })
+                    return false
+
                 val placedUnit = civInfo.units.addUnit(unitName, chosenCity) ?: return false
 
                 val notificationText = getNotificationText(notification, triggerNotificationText,
@@ -78,8 +83,17 @@ object UniqueTriggerActivation {
                 if (chosenCity == null || unit == null || (unit.hasUnique(UniqueType.FoundCity) && civInfo.isOneCityChallenger()))
                     return false
 
+                val limit = unit.getMatchingUniques(UniqueType.MaxNumberBuildable)
+                    .map { it.params[0].toInt() }.minOrNull()
+                val amountFromTriggerable = unique.params[0].toInt()
+                val actualAmount =
+                        if (limit==null) amountFromTriggerable
+                        else civInfo.units.getCivUnits().count { it.name==unitName } - limit
+
+                if (actualAmount <= 0) return false
+
                 val tilesUnitsWerePlacedOn: MutableList<Vector2> = mutableListOf()
-                for (i in 1..unique.params[0].toInt()) {
+                for (i in 1..actualAmount) {
                     val placedUnit = civInfo.units.addUnit(unitName, chosenCity)
                     if (placedUnit != null)
                         tilesUnitsWerePlacedOn.add(placedUnit.getTile().position)
@@ -164,8 +178,9 @@ object UniqueTriggerActivation {
                 civInfo.addNotification(notificationText, NotificationCategory.General, NotificationIcon.Culture)
                 return true
             }
-            UniqueType.OneTimeEnterGoldenAge -> {
-                civInfo.goldenAges.enterGoldenAge()
+            UniqueType.OneTimeEnterGoldenAge, UniqueType.OneTimeEnterGoldenAgeTurns -> {
+                if (unique.type == UniqueType.OneTimeEnterGoldenAgeTurns) civInfo.goldenAges.enterGoldenAge(unique.params[0].toInt())
+                else civInfo.goldenAges.enterGoldenAge()
 
                 val notificationText = getNotificationText(notification, triggerNotificationText,
                     "You enter a Golden Age")
@@ -315,6 +330,38 @@ object UniqueTriggerActivation {
                 return true
             }
 
+            UniqueType.OneTimeProvideResources -> {
+                val amount = unique.params[0].toInt()
+                val resourceName = unique.params[1]
+                val resource = ruleSet.tileResources[resourceName] ?: return false
+                if (!resource.isStockpiled()) return false
+
+                civInfo.resourceStockpiles.add(resourceName, amount)
+
+                val notificationText = getNotificationText(notification, triggerNotificationText,
+                    "You have gained [$amount] [$resourceName]")
+                    ?: return true
+
+                civInfo.addNotification(notificationText, NotificationCategory.General, NotificationIcon.Science, "ResourceIcons/$resourceName")
+                return true
+            }
+
+            UniqueType.OneTimeConsumeResources -> {
+                val amount = unique.params[0].toInt()
+                val resourceName = unique.params[1]
+                val resource = ruleSet.tileResources[resourceName] ?: return false
+                if (!resource.isStockpiled()) return false
+
+                civInfo.resourceStockpiles.add(resourceName, amount)
+
+                val notificationText = getNotificationText(notification, triggerNotificationText,
+                    "You have lost [$amount] [$resourceName]")
+                    ?: return true
+
+                civInfo.addNotification(notificationText, NotificationCategory.General, NotificationIcon.Science, "ResourceIcons/$resourceName")
+                return true
+            }
+
             UniqueType.OneTimeRevealEntireMap -> {
                 if (notification != null) {
                     civInfo.addNotification(notification, LocationAction(tile?.position), NotificationCategory.General, NotificationIcon.Scout)
@@ -351,6 +398,21 @@ object UniqueTriggerActivation {
                 return promotedUnitLocations.isNotEmpty()
             }
 
+            /**
+             * The mechanics for granting great people are wonky, but basically the following happens:
+             * Based on the game speed, a timer with some amount of turns is set, 40 on regular speed
+             * Every turn, 1 is subtracted from this timer, as long as you have at least 1 city state ally
+             * So no, the number of city-state allies does not matter for this. You have a global timer for all of them combined.
+             * If the timer reaches the amount of city-state allies you have (or 10, whichever is lower), it is reset.
+             * You will then receive a random great person from a random city-state you are allied to
+             * The very first time after acquiring this policy, the timer is set to half of its normal value
+             * This is the basics, and apart from this, there is some randomness in the exact turn count, but I don't know how much
+             * There is surprisingly little information findable online about this policy, and the civ 5 source files are
+             *  also quite though to search through, so this might all be incorrect.
+             * For now this mechanic seems decent enough that this is fine.
+             * Note that the way this is implemented now, this unique does NOT stack
+             * I could parametrize the [Allied], but eh.
+             */
             UniqueType.CityStateCanGiftGreatPeople -> {
                 civInfo.addFlag(
                     CivFlags.CityStateGreatPersonGift.name,
@@ -361,21 +423,6 @@ object UniqueTriggerActivation {
                 }
                 return true
             }
-            // The mechanics for granting great people are wonky, but basically the following happens:
-            // Based on the game speed, a timer with some amount of turns is set, 40 on regular speed
-            // Every turn, 1 is subtracted from this timer, as long as you have at least 1 city state ally
-            // So no, the number of city-state allies does not matter for this. You have a global timer for all of them combined.
-            // If the timer reaches the amount of city-state allies you have (or 10, whichever is lower), it is reset.
-            // You will then receive a random great person from a random city-state you are allied to
-            // The very first time after acquiring this policy, the timer is set to half of its normal value
-            // This is the basics, and apart from this, there is some randomness in the exact turn count, but I don't know how much
-
-            // There is surprisingly little information findable online about this policy, and the civ 5 source files are
-            // also quite though to search through, so this might all be incorrect.
-            // For now this mechanic seems decent enough that this is fine.
-
-            // Note that the way this is implemented now, this unique does NOT stack
-            // I could parametrize the [Allied], but eh.
 
             UniqueType.OneTimeGainStat -> {
                 val stat = Stat.safeValueOf(unique.params[1]) ?: return false
@@ -399,6 +446,7 @@ object UniqueTriggerActivation {
                 civInfo.addNotification(notificationText, LocationAction(tile?.position), NotificationCategory.General, stat.notificationIcon)
                 return true
             }
+
             UniqueType.OneTimeGainStatRange -> {
                 val stat = Stat.safeValueOf(unique.params[2]) ?: return false
 
@@ -607,7 +655,8 @@ object UniqueTriggerActivation {
     fun triggerUnitwideUnique(
         unique: Unique,
         unit: MapUnit,
-        notification: String? = null
+        notification: String? = null,
+        triggerNotificationText:String? = null
     ): Boolean {
         when (unique.type) {
             UniqueType.OneTimeUnitHeal -> {
@@ -648,7 +697,7 @@ object UniqueTriggerActivation {
                     unit.civ.addNotification(notification, unit.getTile().position, NotificationCategory.Units, unit.name)
                 return true
             }
-            else -> return triggerCivwideUnique(unique, civInfo = unit.civ, tile=unit.currentTile)
+            else -> return triggerCivwideUnique(unique, civInfo = unit.civ, tile=unit.currentTile, triggerNotificationText = triggerNotificationText)
         }
     }
 }
