@@ -7,7 +7,6 @@ import com.badlogic.gdx.scenes.scene2d.ui.SelectBox
 import com.badlogic.gdx.scenes.scene2d.ui.Table
 import com.badlogic.gdx.utils.Array
 import com.unciv.GUI
-import com.unciv.UncivGame
 import com.unciv.models.metadata.GameSettings
 import com.unciv.models.metadata.ScreenSize
 import com.unciv.models.skins.SkinCache
@@ -24,10 +23,13 @@ import com.unciv.ui.components.extensions.onChange
 import com.unciv.ui.components.extensions.onClick
 import com.unciv.ui.components.extensions.toLabel
 import com.unciv.ui.components.extensions.toTextButton
+import com.unciv.ui.screens.worldscreen.NotificationsScroll
 import com.unciv.utils.Display
 import com.unciv.utils.ScreenMode
 
-
+/**
+ *  @param onChange Callback for _major_ changes, OptionsPopup will rebuild itself and the WorldScreen
+ */
 fun displayTab(
     optionsPopup: OptionsPopup,
     onChange: () -> Unit,
@@ -45,18 +47,21 @@ fun displayTab(
             if (GUI.isWorldLoaded())
                 GUI.getMap().isAutoScrollEnabled = settings.mapAutoScroll
         }
+        addScrollSpeedSlider(this, settings, optionsPopup.selectBoxMinWidth)
     }
 
     optionsPopup.addCheckbox(this, "Show unit movement arrows", settings.showUnitMovements, true) { settings.showUnitMovements = it }
     optionsPopup.addCheckbox(this, "Show tile yields", settings.showTileYields, true) { settings.showTileYields = it } // JN
     optionsPopup.addCheckbox(this, "Show worked tiles", settings.showWorkedTiles, true) { settings.showWorkedTiles = it }
     optionsPopup.addCheckbox(this, "Show resources and improvements", settings.showResourcesAndImprovements, true) { settings.showResourcesAndImprovements = it }
-    optionsPopup.addCheckbox(this, "Show tutorials", settings.showTutorials, true, false) { settings.showTutorials = it }
+    optionsPopup.addCheckbox(this, "Show tutorials", settings.showTutorials, updateWorld = true, newRow = false) { settings.showTutorials = it }
     addResetTutorials(this, settings)
     optionsPopup.addCheckbox(this, "Show pixel improvements", settings.showPixelImprovements, true) { settings.showPixelImprovements = it }
     optionsPopup.addCheckbox(this, "Experimental Demographics scoreboard", settings.useDemographics, true) { settings.useDemographics = it }
     optionsPopup.addCheckbox(this, "Show zoom buttons in world screen", settings.showZoomButtons, true) { settings.showZoomButtons = it }
 
+    addNotificationScrollSelect(this, settings, optionsPopup.selectBoxMinWidth)
+
     addMinimapSizeSlider(this, settings, optionsPopup.selectBoxMinWidth)
 
     addUnitIconAlphaSlider(this, settings, optionsPopup.selectBoxMinWidth)
@@ -114,13 +119,25 @@ private fun addMinimapSizeSlider(table: Table, settings: GameSettings, selectBox
             settings.showMinimap = true
             settings.minimapSize = size
         }
-        val worldScreen = GUI.getWorldScreenIfActive()
-        if (worldScreen != null)
-            GUI.setUpdateWorldOnNextRender()
+        GUI.setUpdateWorldOnNextRender()
     }
     table.add(minimapSlider).minWidth(selectBoxMinWidth).pad(10f).row()
 }
 
+private fun addScrollSpeedSlider(table: Table, settings: GameSettings, selectBoxMinWidth: Float) {
+    table.add("Map panning speed".toLabel()).left().fillX()
+
+    val scrollSpeedSlider = UncivSlider(
+        0.2f, 25f, 0.2f, initial = settings.mapPanningSpeed
+    ) {
+        settings.mapPanningSpeed = it
+        settings.save()
+        if (GUI.isWorldLoaded())
+            GUI.getMap().mapPanningSpeed = settings.mapPanningSpeed
+    }
+    table.add(scrollSpeedSlider).minWidth(selectBoxMinWidth).pad(10f).row()
+}
+
 private fun addUnitIconAlphaSlider(table: Table, settings: GameSettings, selectBoxMinWidth: Float) {
     table.add("Unit icon opacity".toLabel()).left().fillX()
 
@@ -130,11 +147,7 @@ private fun addUnitIconAlphaSlider(table: Table, settings: GameSettings, selectB
         0f, 1f, 0.1f, initial = settings.unitIconOpacity, getTipText = getTipText
     ) {
         settings.unitIconOpacity = it
-
-        val worldScreen = UncivGame.Current.getWorldScreenIfActive()
-        if (worldScreen != null)
-            worldScreen.shouldUpdate = true
-
+        GUI.setUpdateWorldOnNextRender()
     }
     table.add(unitIconAlphaSlider).minWidth(selectBoxMinWidth).pad(10f).row()
 }
@@ -149,6 +162,7 @@ private fun addScreenModeSelectBox(table: Table, settings: GameSettings, selectB
     selectBox.items = Array(modes.values.toTypedArray())
     selectBox.selected = current
     selectBox.onChange {
+        settings.refreshWindowSize()
         val mode = selectBox.selected
         settings.screenMode = mode.getId()
         Display.setScreenMode(mode.getId(), settings)
@@ -160,7 +174,7 @@ private fun addScreenModeSelectBox(table: Table, settings: GameSettings, selectB
 private fun addScreenSizeSelectBox(table: Table, settings: GameSettings, selectBoxMinWidth: Float, onResolutionChange: () -> Unit) {
     table.add("Screen Size".toLabel()).left().fillX()
 
-    val screenSizeSelectBox = TranslatedSelectBox(ScreenSize.values().map { it.name }, settings.screenSize.name,table.skin)
+    val screenSizeSelectBox = TranslatedSelectBox(ScreenSize.values().map { it.name }, settings.screenSize.name, table.skin)
     table.add(screenSizeSelectBox).minWidth(selectBoxMinWidth).pad(10f).row()
 
     screenSizeSelectBox.onChange {
@@ -250,3 +264,19 @@ private fun addResetTutorials(table: Table, settings: GameSettings) {
     }
     table.add(resetTutorialsButton).center().row()
 }
+
+private fun addNotificationScrollSelect(table: Table, settings: GameSettings, selectBoxMinWidth: Float) {
+    table.add("Notifications on world screen".toLabel()).left().fillX()
+
+    val selectBox = TranslatedSelectBox(
+        NotificationsScroll.UserSetting.values().map { it.name },
+        settings.notificationScroll,
+        table.skin
+    )
+    table.add(selectBox).minWidth(selectBoxMinWidth).pad(10f).row()
+
+    selectBox.onChange {
+        settings.notificationScroll = selectBox.selected.value
+        GUI.setUpdateWorldOnNextRender()
+    }
+}
