@@ -23,11 +23,6 @@ import com.unciv.models.ruleset.unit.BaseUnit
 import com.unciv.models.stats.Stat
 import com.unciv.models.translations.tr
 import com.unciv.ui.audio.SoundPlayer
-import com.unciv.ui.images.ImageGetter
-import com.unciv.ui.popups.ConfirmPopup
-import com.unciv.ui.popups.Popup
-import com.unciv.ui.popups.closeAllPopups
-import com.unciv.ui.screens.basescreen.BaseScreen
 import com.unciv.ui.components.ExpanderTab
 import com.unciv.ui.components.UncivTooltip.Companion.addTooltip
 import com.unciv.ui.components.extensions.addBorder
@@ -45,6 +40,11 @@ import com.unciv.ui.components.extensions.packIfNeeded
 import com.unciv.ui.components.extensions.surroundWithCircle
 import com.unciv.ui.components.extensions.toLabel
 import com.unciv.ui.components.extensions.toTextButton
+import com.unciv.ui.images.ImageGetter
+import com.unciv.ui.popups.ConfirmPopup
+import com.unciv.ui.popups.Popup
+import com.unciv.ui.popups.closeAllPopups
+import com.unciv.ui.screens.basescreen.BaseScreen
 import com.unciv.utils.concurrency.Concurrency
 import com.unciv.utils.concurrency.launchOnGLThread
 import kotlin.math.max
@@ -59,7 +59,7 @@ private class ConstructionButtonDTO(
 
 /**
  * Manager to hold and coordinate two widgets for the city screen left side:
- * - Construction queue with switch to [ConstructionInfoTable] button and the enqueue / buy buttons.
+ * - Construction queue with the enqueue / buy buttons.
  *   The queue is scrollable, limited to one third of the stage height.
  * - Available constructions display, scrolling, grouped with expanders and therefore of dynamic height.
  */
@@ -202,7 +202,7 @@ class CityConstructionsTable(private val cityScreen: CityScreen) {
 
             val useStoredProduction = entry is Building || !cityConstructions.isBeingConstructedOrEnqueued(entry.name)
             val buttonText = cityConstructions.getTurnsToConstructionString(entry.name, useStoredProduction).trim()
-            val resourcesRequired = entry.getResourceRequirements()
+            val resourcesRequired = entry.getResourceRequirementsPerTurn()
             val mostImportantRejection =
                     entry.getRejectionReasons(cityConstructions)
                         .filter { it.isImportantRejection() }
@@ -317,9 +317,11 @@ class CityConstructionsTable(private val cityScreen: CityScreen) {
                 if (constructionName in PerpetualConstruction.perpetualConstructionsMap) "\n∞"
                 else cityConstructions.getTurnsToConstructionString(constructionName, isFirstConstructionOfItsKind)
 
-        val constructionResource = cityConstructions.getConstruction(constructionName).getResourceRequirements()
-        for ((resource, amount) in constructionResource)
-            text += "\n" + resource.getConsumesAmountString(amount).tr()
+        val constructionResource = cityConstructions.getConstruction(constructionName).getResourceRequirementsPerTurn()
+        for ((resourceName, amount) in constructionResource) {
+            val resource = cityConstructions.city.getRuleset().tileResources[resourceName] ?: continue
+            text += "\n" + resourceName.getConsumesAmountString(amount, resource.isStockpiled()).tr()
+        }
 
         table.defaults().pad(2f).minWidth(40f)
         if (isFirstConstructionOfItsKind) table.add(getProgressBar(constructionName)).minWidth(5f)
@@ -380,28 +382,35 @@ class CityConstructionsTable(private val cityScreen: CityScreen) {
         pickConstructionButton.add(getProgressBar(construction.name)).padRight(5f)
         pickConstructionButton.add(icon).padRight(10f)
 
-        val table = Table().apply { isTransform = false }
-        val tableRes = Table().apply { isTransform = false }
+        val constructionTable = Table().apply { isTransform = false }
+        val resourceTable = Table().apply { isTransform = false }
 
         val textColor = if (constructionButtonDTO.rejectionReason == null) Color.WHITE else Color.RED
-        table.add(construction.name.tr().toLabel(fontColor = textColor)).expandX().left().row()
+        constructionTable.add(construction.name.toLabel(fontColor = textColor).apply { wrap=true })
+            .width(cityScreen.stage.width/5).expandX().left().row()
 
-        tableRes.add(constructionButtonDTO.buttonText.toLabel()).expandX().left()
+        resourceTable.add(constructionButtonDTO.buttonText.toLabel()).expandX().left()
         if (constructionButtonDTO.resourcesRequired != null) {
             for ((resource, amount) in constructionButtonDTO.resourcesRequired) {
-                if (constructionButtonDTO.rejectionReason?.type == RejectionReasonType.ConsumesResources)
-                    tableRes.add(amount.toString().toLabel(fontColor = Color.RED)).expandX().left().padLeft(5f)
-                else
-                    tableRes.add(amount.toString().toLabel(fontColor = Color.WHITE)).expandX().left().padLeft(5f)
-                tableRes.add(ImageGetter.getResourcePortrait(resource, 15f)).padBottom(1f)
+                val color = if (constructionButtonDTO.rejectionReason?.type == RejectionReasonType.ConsumesResources)
+                    Color.RED else Color.WHITE
+                resourceTable.add(amount.toString().toLabel(fontColor = color)).expandX().left().padLeft(5f)
+                resourceTable.add(ImageGetter.getResourcePortrait(resource, 15f)).padBottom(1f)
             }
         }
-        table.add(tableRes).expandX().left()
+        for (unique in constructionButtonDTO.construction.getMatchingUniquesNotConflicting(UniqueType.CostsResources)){
+            val color = if (constructionButtonDTO.rejectionReason?.type == RejectionReasonType.ConsumesResources)
+                Color.RED else Color.WHITE
+            resourceTable.add(unique.params[0].toLabel(fontColor = color)).expandX().left().padLeft(5f)
+            resourceTable.add(ImageGetter.getResourcePortrait(unique.params[1], 15f)).padBottom(1f)
+        }
+        constructionTable.add(resourceTable).expandX().left()
 
-        pickConstructionButton.add(table).expandX().left()
+        pickConstructionButton.add(constructionTable).expandX().left()
 
         if (!cannotAddConstructionToQueue(construction, cityScreen.city, cityScreen.city.cityConstructions)) {
-            val addToQueueButton = ImageGetter.getImage("OtherIcons/New").apply { color = Color.BLACK }.surroundWithCircle(40f)
+            val addToQueueButton = ImageGetter.getImage("OtherIcons/New")
+                .apply { color = Color.BLACK }.surroundWithCircle(40f)
             addToQueueButton.onClick(UncivSound.Silent) {
                 // Since the pickConstructionButton.onClick adds the construction if it's selected,
                 // this effectively adds the construction even if it's unselected
@@ -418,7 +427,8 @@ class CityConstructionsTable(private val cityScreen: CityScreen) {
             if (constructionButtonDTO.rejectionReason.type != RejectionReasonType.ConsumesResources) {
                 pickConstructionButton.add(constructionButtonDTO.rejectionReason.errorMessage
                     .toLabel(Color.RED).apply { wrap = true })
-                    .colspan(pickConstructionButton.columns).fillX().left().padTop(2f)
+                    .colspan(pickConstructionButton.columns)
+                    .width(cityScreen.stage.width/4).fillX().left().padTop(2f)
             }
         }
 
