@@ -1,26 +1,22 @@
 package com.unciv.ui.screens.newgamescreen
 
 import com.badlogic.gdx.graphics.Color
-import com.badlogic.gdx.scenes.scene2d.Group
 import com.badlogic.gdx.scenes.scene2d.Touchable
 import com.badlogic.gdx.scenes.scene2d.ui.CheckBox
-import com.badlogic.gdx.scenes.scene2d.ui.ImageButton
 import com.badlogic.gdx.scenes.scene2d.ui.Table
 import com.badlogic.gdx.utils.Align
+import com.unciv.Constants
 import com.unciv.UncivGame
+import com.unciv.logic.civilization.PlayerType
 import com.unciv.models.metadata.GameParameters
+import com.unciv.models.metadata.Player
 import com.unciv.models.ruleset.RulesetCache
 import com.unciv.models.ruleset.nation.Nation
 import com.unciv.models.ruleset.unique.UniqueType
 import com.unciv.models.translations.tr
 import com.unciv.ui.audio.MusicMood
 import com.unciv.ui.audio.MusicTrackChooserFlags
-import com.unciv.ui.images.ImageGetter
-import com.unciv.ui.screens.multiplayerscreens.MultiplayerHelpers
-import com.unciv.ui.popups.Popup
-import com.unciv.ui.popups.ToastPopup
 import com.unciv.ui.components.AutoScrollPane
-import com.unciv.ui.screens.basescreen.BaseScreen
 import com.unciv.ui.components.ExpanderTab
 import com.unciv.ui.components.KeyCharAndCode
 import com.unciv.ui.components.UncivSlider
@@ -29,15 +25,22 @@ import com.unciv.ui.components.extensions.onActivation
 import com.unciv.ui.components.extensions.onChange
 import com.unciv.ui.components.extensions.onClick
 import com.unciv.ui.components.extensions.pad
-import com.unciv.ui.components.extensions.surroundWithCircle
 import com.unciv.ui.components.extensions.toCheckBox
+import com.unciv.ui.components.extensions.toImageButton
 import com.unciv.ui.components.extensions.toLabel
 import com.unciv.ui.components.extensions.toTextButton
+import com.unciv.ui.images.ImageGetter
+import com.unciv.ui.popups.Popup
+import com.unciv.ui.popups.ToastPopup
+import com.unciv.ui.screens.basescreen.BaseScreen
+import com.unciv.ui.screens.multiplayerscreens.MultiplayerHelpers
+import kotlin.reflect.KMutableProperty0
 
 class GameOptionsTable(
     private val previousScreen: IPreviousScreen,
     private val isPortrait: Boolean = false,
-    private val updatePlayerPickerTable: (desiredCiv:String)->Unit
+    private val updatePlayerPickerTable: (desiredCiv: String) -> Unit,
+    private val updatePlayerPickerRandomLabel: () -> Unit
 ) : Table(BaseScreen.skin) {
     var gameParameters = previousScreen.gameSetupInfo.gameParameters
     val ruleset = previousScreen.ruleset
@@ -79,12 +82,10 @@ class GameOptionsTable(
                 if (turnSlider != null)
                     add(turnSlider).padTop(10f).row()
                 if (gameParameters.randomNumberOfPlayers) {
-                    addMinPlayersSlider()
-                    addMaxPlayersSlider()
+                    addMinMaxPlayersSliders()
                 }
                 if (gameParameters.randomNumberOfCityStates) {
-                    addMinCityStatesSlider()
-                    addMaxCityStatesSlider()
+                    addMinMaxCityStatesSliders()
                 } else {
                     addCityStatesSlider()
                 }
@@ -206,13 +207,12 @@ class GameOptionsTable(
         add(button)
     }
 
-    private fun numberOfPlayable() = ruleset.nations.values.count {
-        it.isMajorCiv()
+    private fun numberOfMajorCivs() = ruleset.nations.values.count {
+        it.isMajorCiv
     }
 
     private fun numberOfCityStates() = ruleset.nations.values.count {
-        it.isCityState()
-        && !it.hasUnique(UniqueType.CityStateDeprecated)
+        it.isCityState && !it.hasUnique(UniqueType.CityStateDeprecated)
     }
 
     private fun Table.addNoStartBiasCheckbox() =
@@ -221,64 +221,101 @@ class GameOptionsTable(
 
     private fun Table.addRandomPlayersCheckbox() =
             addCheckbox("Random number of Civilizations", gameParameters.randomNumberOfPlayers)
-            {
-                gameParameters.randomNumberOfPlayers = it
+            {newRandomNumberOfPlayers ->
+                gameParameters.randomNumberOfPlayers = newRandomNumberOfPlayers
+                if (newRandomNumberOfPlayers) {
+                    // remove all random AI from player picker
+                    val newPlayers = gameParameters.players.asSequence()
+                        .filterNot { it.playerType == PlayerType.AI && it.chosenCiv == Constants.random }
+                        .toCollection(ArrayList(gameParameters.players.size))
+                    if (newPlayers.size != gameParameters.players.size) {
+                        gameParameters.players = newPlayers
+                        updatePlayerPickerTable("")
+                    }
+                } else {
+                    // Fill up player picker with random AI until previously active min reached
+                    val additionalRandom = gameParameters.minNumberOfPlayers - gameParameters.players.size
+                    if (additionalRandom > 0) {
+                        repeat(additionalRandom) {
+                            gameParameters.players.add(Player(Constants.random))
+                        }
+                        updatePlayerPickerTable("")
+                    }
+                }
                 update()  // To see the new sliders
             }
 
     private fun Table.addRandomCityStatesCheckbox() =
             addCheckbox("Random number of City-States", gameParameters.randomNumberOfCityStates)
             {
-                gameParameters.randomNumberOfCityStates = it
+                gameParameters.run {
+                    randomNumberOfCityStates = it
+                    if (it) {
+                        if (numberOfCityStates > maxNumberOfCityStates)
+                            maxNumberOfCityStates = numberOfCityStates
+                        if (numberOfCityStates < minNumberOfCityStates)
+                            minNumberOfCityStates = numberOfCityStates
+                    } else {
+                        if (numberOfCityStates > maxNumberOfCityStates)
+                            numberOfCityStates = maxNumberOfCityStates
+                        if (numberOfCityStates < minNumberOfCityStates)
+                            numberOfCityStates = minNumberOfCityStates
+                    }
+                }
                 update()  // To see the changed sliders
             }
 
-    private fun Table.addMinPlayersSlider() {
-        val playableAvailable = numberOfPlayable()
-        if (playableAvailable == 0) return
+    private fun Table.addLinkedMinMaxSliders(
+        minValue: Int, maxValue: Int,
+        minText: String, maxText: String,
+        minField: KMutableProperty0<Int>,
+        maxField: KMutableProperty0<Int>,
+        onChangeCallback: (() -> Unit)? = null
+    ) {
+        if (maxValue < minValue) return
 
-        add("{Min number of Civilizations}:".toLabel()).left().expandX()
-        val slider = UncivSlider(2f, playableAvailable.toFloat(), 1f, initial = gameParameters.minNumberOfPlayers.toFloat()) {
-            gameParameters.minNumberOfPlayers = it.toInt()
+        @Suppress("JoinDeclarationAndAssignment")  // it's a forward declaration!
+        lateinit var maxSlider: UncivSlider  // lateinit safe because the closure won't use it until the user operates a slider
+        val minSlider = UncivSlider(minValue.toFloat(), maxValue.toFloat(), 1f, initial = minField.get().toFloat()) {
+            val newMin = it.toInt()
+            minField.set(newMin)
+            if (newMin > maxSlider.value.toInt()) {
+                maxSlider.value = it
+                maxField.set(newMin)
+            }
+            onChangeCallback?.invoke()
         }
-        slider.isDisabled = locked
-        add(slider).padTop(10f).row()
+        minSlider.isDisabled = locked
+        maxSlider = UncivSlider(minValue.toFloat(), maxValue.toFloat(), 1f, initial = maxField.get().toFloat()) {
+            val newMax = it.toInt()
+            maxField.set(newMax)
+            if (newMax < minSlider.value.toInt()) {
+                minSlider.value = it
+                minField.set(newMax)
+            }
+            onChangeCallback?.invoke()
+        }
+        maxSlider.isDisabled = locked
+
+        add(minText.toLabel()).left().expandX()
+        add(minSlider).padTop(10f).row()
+        add(maxText.toLabel()).left().expandX()
+        add(maxSlider).padTop(10f).row()
     }
 
-    private fun Table.addMaxPlayersSlider() {
-        val playableAvailable = numberOfPlayable()
-        if (playableAvailable == 0) return
-
-        add("{Max number of Civilizations}:".toLabel()).left().expandX()
-        val slider = UncivSlider(2f, playableAvailable.toFloat(), 1f, initial = gameParameters.maxNumberOfPlayers.toFloat()) {
-            gameParameters.maxNumberOfPlayers = it.toInt()
-        }
-        slider.isDisabled = locked
-        add(slider).padTop(10f).row()
+    private fun Table.addMinMaxPlayersSliders() {
+        addLinkedMinMaxSliders(2, numberOfMajorCivs(),
+            "{Min number of Civilizations}:", "{Max number of Civilizations}:",
+            gameParameters::minNumberOfPlayers, gameParameters::maxNumberOfPlayers,
+            updatePlayerPickerRandomLabel
+        )
     }
 
-    private fun Table.addMinCityStatesSlider() {
-        val cityStatesAvailable = numberOfCityStates()
-        if (cityStatesAvailable == 0) return
-
-        add("{Min number of City-States}:".toLabel()).left().expandX()
-        val slider = UncivSlider(0f, cityStatesAvailable.toFloat(), 1f, initial = gameParameters.minNumberOfCityStates.toFloat()) {
-            gameParameters.minNumberOfCityStates = it.toInt()
-        }
-        slider.isDisabled = locked
-        add(slider).padTop(10f).row()
-    }
-
-    private fun Table.addMaxCityStatesSlider() {
-        val cityStatesAvailable = numberOfCityStates()
-        if (cityStatesAvailable == 0) return
-
-        add("{Max number of City-States}:".toLabel()).left().expandX()
-        val slider = UncivSlider(0f, cityStatesAvailable.toFloat(), 1f, initial = gameParameters.maxNumberOfCityStates.toFloat()) {
-            gameParameters.maxNumberOfCityStates = it.toInt()
-        }
-        slider.isDisabled = locked
-        add(slider).padTop(10f).row()
+    private fun Table.addMinMaxCityStatesSliders() {
+        addLinkedMinMaxSliders( 0, numberOfCityStates(),
+            "{Min number of City-States}:", "{Max number of City-States}:",
+            gameParameters::minNumberOfCityStates, gameParameters::maxNumberOfCityStates
+        )
     }
 
     private fun Table.addCityStatesSlider() {
@@ -434,7 +471,7 @@ class GameOptionsTable(
 
         var desiredCiv = ""
         if (gameParameters.mods.contains(mod)) {
-            val modNations = RulesetCache[mod]?.nations?.values?.filter { it.isMajorCiv() }
+            val modNations = RulesetCache[mod]?.nations?.values?.filter { it.isMajorCiv }
 
             if (modNations != null && modNations.any())
                 desiredCiv = modNations.random().name
@@ -481,7 +518,7 @@ private class RandomNationPickerPopup(
 
     init {
         val sortedNations = previousScreen.ruleset.nations.values
-                .filter { it.isMajorCiv() }
+                .filter { it.isMajorCiv }
                 .sortedWith(compareBy(UncivGame.Current.settings.getCollatorFromLocale()) { it.name.tr() })
         allNationTables = ArrayList(
             sortedNations.map { NationTable(it, civBlocksWidth, 0f) }  // no need for min height
@@ -547,16 +584,8 @@ private class RandomNationPickerPopup(
         }
     }
 
-    private fun String.toImageButton(overColor: Color): Group {
-        val style = ImageButton.ImageButtonStyle()
-        val image = ImageGetter.getDrawable(this)
-        style.imageUp = image
-        style.imageOver = image.tint(overColor)
-        val button = ImageButton(style)
-        button.setSize(buttonsIconSize, buttonsIconSize)
-
-        return button.surroundWithCircle(buttonsCircleSize, false, buttonsBackColor)
-    }
+    private fun String.toImageButton(overColor: Color) =
+            toImageButton(buttonsIconSize, buttonsCircleSize, buttonsBackColor, overColor)
 
     private fun addNationToPool(nation: Nation) {
         availableNations.remove(nation.name)
