@@ -26,6 +26,7 @@ import com.unciv.logic.city.City
 import com.unciv.logic.civilization.Civilization
 import com.unciv.logic.map.TileMap
 import com.unciv.logic.map.mapunit.MapUnit
+import com.unciv.logic.map.mapunit.UnitMovement
 import com.unciv.logic.map.tile.Tile
 import com.unciv.models.UncivSound
 import com.unciv.models.helpers.MapArrowType
@@ -266,9 +267,12 @@ class WorldMapHolder(
             try {
                 tileToMoveTo = selectedUnit.movement.getTileToMoveToThisTurn(targetTile)
             } catch (ex: Exception) {
-                Log.error("Exception in getTileToMoveToThisTurn", ex)
-                return@run
-            } // can't move here
+                // This is normal e.g. when selecting an air unit then right-clicking on an empty tile
+                // Or telling a ship to run onto a coastal land tile.
+                if (ex !is UnitMovement.UnreachableDestinationException)
+                    Log.error("Exception in getTileToMoveToThisTurn", ex)
+                return@run // can't move here
+            }
 
             worldScreen.preActionGameInfo = worldScreen.gameInfo.clone()
 
