@@ -12,29 +12,32 @@ import com.badlogic.gdx.utils.Align
 import com.unciv.logic.civilization.Civilization
 import com.unciv.models.ruleset.tile.ResourceType
 import com.unciv.models.ruleset.tile.TileResource
+import com.unciv.models.ruleset.unique.UniqueType
 import com.unciv.models.stats.Stats
 import com.unciv.models.translations.tr
-import com.unciv.ui.screens.civilopediascreen.CivilopediaCategories
-import com.unciv.ui.screens.civilopediascreen.CivilopediaScreen
-import com.unciv.ui.images.ImageGetter
-import com.unciv.ui.screens.overviewscreen.EmpireOverviewScreen
-import com.unciv.ui.screens.pickerscreens.PolicyPickerScreen
-import com.unciv.ui.screens.pickerscreens.TechPickerScreen
-import com.unciv.ui.popups.popups
-import com.unciv.ui.screens.basescreen.BaseScreen
 import com.unciv.ui.components.Fonts
 import com.unciv.ui.components.MayaCalendar
 import com.unciv.ui.components.UncivTooltip.Companion.addTooltip
+import com.unciv.ui.components.YearTextUtil
 import com.unciv.ui.components.extensions.colorFromRGB
 import com.unciv.ui.components.extensions.darken
 import com.unciv.ui.components.extensions.onClick
 import com.unciv.ui.components.extensions.setFontColor
 import com.unciv.ui.components.extensions.setFontSize
 import com.unciv.ui.components.extensions.toLabel
+import com.unciv.ui.components.extensions.toStringSigned
 import com.unciv.ui.components.extensions.toTextButton
+import com.unciv.ui.images.ImageGetter
+import com.unciv.ui.popups.popups
+import com.unciv.ui.screens.basescreen.BaseScreen
+import com.unciv.ui.screens.civilopediascreen.CivilopediaCategories
+import com.unciv.ui.screens.civilopediascreen.CivilopediaScreen
+import com.unciv.ui.screens.overviewscreen.EmpireOverviewCategories
+import com.unciv.ui.screens.overviewscreen.EmpireOverviewScreen
+import com.unciv.ui.screens.pickerscreens.PolicyPickerScreen
+import com.unciv.ui.screens.pickerscreens.TechPickerScreen
 import com.unciv.ui.screens.victoryscreen.VictoryScreen
 import com.unciv.ui.screens.worldscreen.mainmenu.WorldScreenMenuPopup
-import kotlin.math.abs
 import kotlin.math.ceil
 import kotlin.math.max
 import kotlin.math.roundToInt
@@ -45,7 +48,7 @@ import kotlin.math.roundToInt
  */
 //region Fields
 class WorldScreenTopBar(val worldScreen: WorldScreen) : Table() {
-
+    //TODO shouldn't most onClick be addActivationAction instead?
     private val turnsLabel = "Turns: 0/400".toLabel()
     private val goldLabel = "0".toLabel(colorFromRGB(225, 217, 71))
     private val scienceLabel = "0".toLabel(colorFromRGB(78, 140, 151))
@@ -104,23 +107,23 @@ class WorldScreenTopBar(val worldScreen: WorldScreen) : Table() {
                 if (!isLast) padRight(20f)
             }
         }
-        fun addStat(label: Label, icon: String, overviewPage: String, isLast: Boolean = false) =
+        fun addStat(label: Label, icon: String, overviewPage: EmpireOverviewCategories, isLast: Boolean = false) =
             addStat(label, icon, isLast) { EmpireOverviewScreen(worldScreen.selectedCiv, overviewPage) }
 
-        addStat(goldLabel, "Gold", "Stats")
+        addStat(goldLabel, "Gold", EmpireOverviewCategories.Stats)
         addStat(scienceLabel, "Science") { TechPickerScreen(worldScreen.selectedCiv) }
 
         statsTable.add(happinessImage).padBottom(6f).size(20f)
         statsTable.add(happinessLabel).padRight(20f)
         val invokeResourcesPage = {
-            worldScreen.game.pushScreen(EmpireOverviewScreen(worldScreen.selectedCiv, "Resources"))
+            worldScreen.openEmpireOverview(EmpireOverviewCategories.Resources)
         }
         happinessImage.onClick(invokeResourcesPage)
         happinessLabel.onClick(invokeResourcesPage)
 
-        addStat(cultureLabel, "Culture") { PolicyPickerScreen(worldScreen, worldScreen.selectedCiv) }
+        addStat(cultureLabel, "Culture") { PolicyPickerScreen(worldScreen.selectedCiv, worldScreen.canChangeState) }
         if (worldScreen.gameInfo.isReligionEnabled()) {
-            addStat(faithLabel, "Faith", "Religion", isLast = true)
+            addStat(faithLabel, "Faith", EmpireOverviewCategories.Religion, isLast = true)
         } else {
             statsTable.add("Religion: Off".toLabel())
         }
@@ -145,7 +148,7 @@ class WorldScreenTopBar(val worldScreen: WorldScreen) : Table() {
             }
         }
         resourcesWrapper.onClick {
-            worldScreen.game.pushScreen(EmpireOverviewScreen(worldScreen.selectedCiv, "Resources"))
+            worldScreen.openEmpireOverview(EmpireOverviewCategories.Resources)
         }
 
         val strategicResources = worldScreen.gameInfo.ruleset.tileResources.values
@@ -174,12 +177,12 @@ class WorldScreenTopBar(val worldScreen: WorldScreen) : Table() {
 
         init {
             unitSupplyImage.onClick {
-                worldScreen.game.pushScreen(EmpireOverviewScreen(worldScreen.selectedCiv, "Units"))
+                worldScreen.openEmpireOverview(EmpireOverviewCategories.Units)
             }
 
             val overviewButton = "Overview".toTextButton()
             overviewButton.addTooltip('e')
-            overviewButton.onClick { worldScreen.game.pushScreen(EmpireOverviewScreen(worldScreen.selectedCiv)) }
+            overviewButton.onClick { worldScreen.openEmpireOverview() }
 
             unitSupplyCell = add()
             add(overviewButton).pad(10f)
@@ -225,7 +228,7 @@ class WorldScreenTopBar(val worldScreen: WorldScreen) : Table() {
             }
 
             selectedCivIconHolder.onClick {
-                worldScreen.game.pushScreen(EmpireOverviewScreen(worldScreen.selectedCiv))
+                worldScreen.openEmpireOverview()
             }
 
             add(menuButton).size(50f).padRight(0f)
@@ -340,21 +343,29 @@ class WorldScreenTopBar(val worldScreen: WorldScreen) : Table() {
     }
 
     private fun updateResourcesTable(civInfo: Civilization) {
-        val year = civInfo.gameInfo.getYear()
-        val yearText = if (civInfo.isLongCountDisplay()) MayaCalendar.yearToMayaDate(year)
-        else "[" + abs(year) + "] " + (if (year < 0) "BC" else "AD")
-        turnsLabel.setText(Fonts.turn + "" + civInfo.gameInfo.turns + " | " + yearText.tr())
-
+        val yearText = YearTextUtil.toYearText(
+            civInfo.gameInfo.getYear(), civInfo.isLongCountDisplay()
+        )
+        turnsLabel.setText(Fonts.turn + "" + civInfo.gameInfo.turns + " | " + yearText)
         resourcesWrapper.clearChildren()
         var firstPadLeft = 20f  // We want a distance from the turns entry to the first resource, but only if any resource is displayed
-        val civResources = civInfo.getCivResources()
+        val civResources = civInfo.getCivResourcesByName()
+        val civResourceSupply = civInfo.getCivResourceSupply()
         for ((resource, label, icon) in resourceActors) {
             if (resource.revealedBy != null && !civInfo.tech.isResearched(resource.revealedBy!!))
                 continue
+            if (resource.hasUnique(UniqueType.NotShownOnWorldScreen)) continue
+
             resourcesWrapper.add(icon).padLeft(firstPadLeft).padRight(0f)
             firstPadLeft = 5f
-            val amount = civResources.get(resource, "All")?.amount ?: 0
-            label.setText(amount)
+            val amount = civResources[resource.name] ?: 0
+            if (!resource.isStockpiled())
+                label.setText(amount)
+            else {
+                val perTurn = civResourceSupply.firstOrNull { it.resource == resource }?.amount ?: 0
+                if (perTurn == 0) label.setText(amount)
+                else label.setText("$amount (${perTurn.toStringSigned()})")
+            }
             resourcesWrapper.add(label).padTop(8f)  // digits don't have descenders, so push them down a little
         }
 
