@@ -4,7 +4,6 @@ import com.badlogic.gdx.graphics.Color
 import com.badlogic.gdx.scenes.scene2d.Touchable
 import com.badlogic.gdx.scenes.scene2d.ui.Label
 import com.badlogic.gdx.scenes.scene2d.ui.Table
-import com.unciv.UncivGame
 import com.unciv.logic.automation.unit.AttackableTile
 import com.unciv.logic.automation.unit.BattleHelper
 import com.unciv.logic.automation.unit.UnitAutomation
@@ -31,6 +30,7 @@ import com.unciv.ui.screens.basescreen.BaseScreen
 import com.unciv.ui.screens.worldscreen.WorldScreen
 import com.unciv.ui.screens.worldscreen.bottombar.BattleTableHelpers.flashWoundedCombatants
 import com.unciv.ui.screens.worldscreen.bottombar.BattleTableHelpers.getHealthBar
+import com.unciv.utils.DebugUtils
 import kotlin.math.max
 import kotlin.math.roundToInt
 
@@ -71,7 +71,14 @@ class BattleTable(val worldScreen: WorldScreen): Table() {
         } else {
             val defender = tryGetDefender() ?: return hide()
             if (attacker is CityCombatant && defender is CityCombatant) return hide()
-            simulateBattle(attacker, defender)
+            val tileToAttackFrom = if (attacker is MapUnitCombatant)
+                BattleHelper.getAttackableEnemies(
+                    attacker.unit,
+                    attacker.unit.movement.getDistanceToTiles()
+                )
+                    .firstOrNull { it.tileToAttack == defender.getTile() }?.tileToAttackFrom ?: attacker.getTile()
+            else attacker.getTile()
+            simulateBattle(attacker, defender, tileToAttackFrom)
         }
 
         isVisible = true
@@ -83,7 +90,7 @@ class BattleTable(val worldScreen: WorldScreen): Table() {
         val unitTable = worldScreen.bottomUnitTable
         return if (unitTable.selectedUnit != null
                 && !unitTable.selectedUnit!!.isCivilian()
-                && !unitTable.selectedUnit!!.hasUnique(UniqueType.CannotAttack))
+                && !unitTable.selectedUnit!!.hasUnique(UniqueType.CannotAttack))  // purely cosmetic - hide battle table
                     MapUnitCombatant(unitTable.selectedUnit!!)
         else if (unitTable.selectedCity != null)
             CityCombatant(unitTable.selectedCity!!)
@@ -102,15 +109,12 @@ class BattleTable(val worldScreen: WorldScreen): Table() {
         if (defender == null || (!includeFriendly && defender.getCivInfo() == attackerCiv))
             return null  // no enemy combatant in tile
 
-        val canSeeDefender =
-            if (UncivGame.Current.viewEntireMapForDebug) true
-            else {
-                when {
-                    defender.isInvisible(attackerCiv) -> attackerCiv.viewableInvisibleUnitsTiles.contains(selectedTile)
-                    defender.isCity() -> attackerCiv.hasExplored(selectedTile)
-                    else -> attackerCiv.viewableTiles.contains(selectedTile)
-                }
-            }
+        val canSeeDefender = when {
+            DebugUtils.VISIBLE_MAP -> true
+            defender.isInvisible(attackerCiv) -> attackerCiv.viewableInvisibleUnitsTiles.contains(selectedTile)
+            defender.isCity() -> attackerCiv.hasExplored(selectedTile)
+            else -> attackerCiv.viewableTiles.contains(selectedTile)
+        }
 
         if (!canSeeDefender) return null
 
@@ -136,7 +140,7 @@ class BattleTable(val worldScreen: WorldScreen): Table() {
         add(modifierLabel).width(quarterScreen - upOrDownLabel.minWidth)
     }
 
-    private fun simulateBattle(attacker: ICombatant, defender: ICombatant){
+    private fun simulateBattle(attacker: ICombatant, defender: ICombatant, tileToAttackFrom: Tile){
         clear()
 
         val attackerNameWrapper = Table()
@@ -163,12 +167,12 @@ class BattleTable(val worldScreen: WorldScreen): Table() {
         add(defender.getDefendingStrength(attacker.isRanged()).toString() + defenceIcon).row()
 
         val attackerModifiers =
-                BattleDamage.getAttackModifiers(attacker, defender).map {
+                BattleDamage.getAttackModifiers(attacker, defender, tileToAttackFrom).map {
                     getModifierTable(it.key, it.value)
                 }
         val defenderModifiers =
                 if (defender is MapUnitCombatant)
-                    BattleDamage.getDefenceModifiers(attacker, defender).map {
+                    BattleDamage.getDefenceModifiers(attacker, defender, tileToAttackFrom).map {
                         getModifierTable(it.key, it.value)
                     }
                 else listOf()
@@ -181,8 +185,8 @@ class BattleTable(val worldScreen: WorldScreen): Table() {
 
         if (attackerModifiers.any() || defenderModifiers.any()){
             addSeparator()
-            val attackerStrength = BattleDamage.getAttackingStrength(attacker, defender).roundToInt()
-            val defenderStrength = BattleDamage.getDefendingStrength(attacker, defender).roundToInt()
+            val attackerStrength = BattleDamage.getAttackingStrength(attacker, defender, tileToAttackFrom).roundToInt()
+            val defenderStrength = BattleDamage.getDefendingStrength(attacker, defender, tileToAttackFrom).roundToInt()
             add(attackerStrength.toString() + attackIcon)
             add(defenderStrength.toString() + attackIcon).row()
         }
@@ -195,12 +199,12 @@ class BattleTable(val worldScreen: WorldScreen): Table() {
             row()
         }
 
-        val maxDamageToDefender = BattleDamage.calculateDamageToDefender(attacker, defender, 1f)
-        val minDamageToDefender = BattleDamage.calculateDamageToDefender(attacker, defender, 0f)
+        val maxDamageToDefender = BattleDamage.calculateDamageToDefender(attacker, defender, tileToAttackFrom, 1f)
+        val minDamageToDefender = BattleDamage.calculateDamageToDefender(attacker, defender, tileToAttackFrom, 0f)
         var expectedDamageToDefenderForHealthbar = (maxDamageToDefender + minDamageToDefender) / 2
 
-        val maxDamageToAttacker = BattleDamage.calculateDamageToAttacker(attacker, defender, 1f)
-        val minDamageToAttacker = BattleDamage.calculateDamageToAttacker(attacker, defender, 0f)
+        val maxDamageToAttacker = BattleDamage.calculateDamageToAttacker(attacker, defender, tileToAttackFrom, 1f)
+        val minDamageToAttacker = BattleDamage.calculateDamageToAttacker(attacker, defender, tileToAttackFrom, 0f)
         var expectedDamageToAttackerForHealthbar = (maxDamageToAttacker + minDamageToAttacker) / 2
 
         if (expectedDamageToAttackerForHealthbar > attacker.getHealth() && expectedDamageToDefenderForHealthbar > defender.getHealth()) {
